
===============
Main Developers
===============

The following lists the authors (active ones are bold) that contributed to upstream (or to some fork) of logki:


  * **Tomas Fiedor**: |github| `tfiedor <https://github.com/tfiedor>`_ |email| `TomasFiedor@gmail.com <mailto: TomasFiedor@gmail.com>`_ (original author)

.. |github| image:: ./figs/icon-github.svg
.. |email| image:: ./figs/icon-email.svg
